﻿using DontHarmDesktop.Models;
using DontHarmDesktop.Properties;
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Threading.Tasks;
using System.Windows;

namespace DontHarmDesktop
{
    /// <summary>
    /// Логика взаимодействия для App.xaml
    /// </summary>
    public partial class App : Application
    {
        public static Models.Entities Context { get; } = new Models.Entities();
        public static Models.users CurrentUser = null;

        /// <summary>
        /// Дата входа пользователя
        /// </summary>
        public static DateTime LogOnTime = new DateTime();

        /// <summary>
        /// Дата конца сеанса (только для лаборанта)
        /// </summary>
        public static DateTime LogOffTime = new DateTime();

        /// <summary>
        /// Заблокирован ли вход в текущий момент?
        /// </summary>
        public static bool BlockedLogon = false;

        /// <summary>
        /// Если вход заблокирован, авторизация запрещена если AllowedLogonTime больше текущего времени
        /// </summary>
        public static DateTime AllowedLogonTime;

        /// <summary>
        /// Число провальных попыток входа, выполненных подряд
        /// </summary>
        private static int FailedAttemptsCount = 0;

        public static void BlockLogon(DateTime dateTime)
        {
            if (AllowedLogonTime == null || AllowedLogonTime < dateTime)
            {
                AllowedLogonTime = dateTime;
                BlockedLogon = true;
            }
        }

        /// <summary>
        /// Авторизует пользователя
        /// </summary>
        /// <param name="login">Логин</param>
        /// <param name="password">Пароль</param>
        /// <returns>Успешна ли прошла авторизация</returns>
        public static bool LogOn(string login, string password)
        {
            if (BlockedLogon)
            {
                if (DateTime.Now < AllowedLogonTime)
                {
                    MessageBox.Show("Вход заблокирован до " + AllowedLogonTime);
                    AddLogOnRecord(login, false);
                    return false;
                } else
                {
                    BlockedLogon = false;
                }
            }
            
            var result = Context.users.FirstOrDefault(p => p.login == login && p.password == password);
            if (result == null)
            {
                MessageBox.Show("Логин или пароль не совпадают");
                FailedAttemptsCount++;

                if (FailedAttemptsCount == 2)
                {
                    BlockLogon(DateTime.Now + TimeSpan.FromSeconds(10));
                }
                AddLogOnRecord(login, false);
                return false;
            }

            FailedAttemptsCount = 0;
            CurrentUser = result;
            LogOnTime = DateTime.Now;

            // Вычисление даты выхода кварцевания (2 минуты)
            LogOffTime = LogOnTime + TimeSpan.FromMinutes(2);

            // Запуск таймера
            if (CurrentUser.role == 3 || CurrentUser.role == 4)
            {
                (Current.MainWindow as MainWindow).StartLogoffTimer();
            }

            AddLogOnRecord(login, true);
            return true;
        }

        /// <summary>
        /// Выполняет выход пользователя
        /// </summary>
        public static void LogOff()
        {
            CurrentUser = null;

            // Тут надо проверить роль пользователя
            (Current.MainWindow as MainWindow).StopLogoffTimer();
        }

        private static void AddLogOnRecord(string login, bool successfull)
        {
            var record = new login_attempts();
            record.successfull = Convert.ToByte(successfull);
            record.login = login;
            record.ip_address = "127.0.0.1";
            record.created_at = DateTime.Now;
            Context.login_attempts.Add(record);
            Context.SaveChanges();
        }
    }
}
