﻿using DontHarmDesktop.Pages;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace DontHarmDesktop
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// Таймер принуждённого выхода из приложения
        /// </summary>
        DispatcherTimer logout_timer = new DispatcherTimer();

        /// <summary>
        /// Было ли показано предупреждение о скором выходе из системы
        /// </summary>
        bool shown_logoff_warning = false;

        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Запускает таймер выхода
        /// </summary>
        public void StartLogoffTimer()
        {
            shown_logoff_warning = false;
            logout_timer.Tick += Logout_timer_Tick;
            logout_timer.Interval = new TimeSpan(0, 0, 1);
            logout_timer.Start();
        }

        public void StopLogoffTimer()
        {
            logout_timer.Stop();
            MainFrame.Navigate(new AuthPage());
            TimerTextBlock.Text = String.Empty;
        }

        /// <summary>
        /// callback таймера выхода
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Logout_timer_Tick(object sender, EventArgs e)
        {
            // Проверяем закончилось ли время
            // Проверку роли не выполняем, т.к. таймер даже не начинается если роль не подходит
            if (DateTime.Now > App.LogOffTime)
            {
                App.BlockLogon(DateTime.Now + TimeSpan.FromMinutes(2));
                App.LogOff();
            }

            // Вычисление остатка времени
            var TimeDifference = App.LogOffTime - DateTime.Now;

            if (!shown_logoff_warning && TimeDifference.TotalMinutes < 1)
            {
                MessageBox.Show("Скоро будет произведено кварцевание! Выход из приложения через 1 минуту");
                shown_logoff_warning = true;
            }

            TimerTextBlock.Text = "Минут до кварцевания: " + Math.Round(TimeDifference.TotalMinutes, 0);
        }
    }
}
